==> kicad_0.0.20090216.orig.tar.gz: kicad-0.0.20090216.orig/kicad/include/bitmaps.h <==

// Largeur du toolbar vertical
#define VTOOLBAR_WIDTH  26

// dimension d'un tool vertical
#define TOOL_SIZE       23

// Please keep list sorted alphabetically, ignoring case.

extern const char* shape_3d_xpm[];
extern const char* add_arc_xpm[];
extern const char* add_bus2bus_xpm[];
extern const char* add_bus_xpm[];
extern const char* add_circle_xpm[];
extern const char* add_component_xpm[];
extern const char* add_corner_xpm[];
extern const char* add_cotation_xpm[];
extern const char* add_dashed_line_xpm[];
extern const char* add_entry_xpm[];
extern const char* add_glabel_xpm[];
extern const char* add_hierarchical_label_xpm[];
extern const char* add_hierarchical_subsheet_xpm[];
extern const char* add_hierar_pin_xpm[];
extern const char* add_junction_xpm[];
extern const char* add_line2bus_xpm[];
extern const char* add_line_label_xpm[];
extern const char* add_line_xpm[];
extern const char* add_mires_xpm[];
extern const char* add_polygon_xpm[];
extern const char* add_power_xpm[];
extern const char* add_rectangle_xpm[];
extern const char* add_text_xpm[];
extern const char* add_tracks_xpm[];
extern const char* add_zone_cutout[];
extern const char* add_zone_xpm[];
extern const char* a_icon_pcbnew_xpm[];
extern const char* anchor_xpm[];
extern const char* annotate_down_right_xpm[];
extern const char* annotate_right_down_xpm[];
extern const char* annotate_xpm[];
extern const char* apply_xpm[];
extern const char* auto_associe_xpm[];
extern const char* auto_delete_track_xpm[];
extern const char* auto_track_width_xpm[];
extern const char* axis3d_back_xpm[];
extern const char* axis3d_bottom_xpm[];
extern const char* axis3d_front_xpm[];
extern const char* axis3d_left_xpm[];
extern const char* axis3d_right_xpm[];
extern const char* axis3d_top_xpm[];
extern const char* axis3d_xpm[];
extern const char* backanno_xpm[];
extern const char* book_xpm[];
extern const char* break_bus_xpm[];
extern const char* break_line_xpm[];
extern const char* browse_files_xpm[];
extern const char* cancel_tool_xpm[];
extern const char* cancel_xpm[];
extern const char* component_select_alternate_shape_xpm[];
extern const char* component_select_unit_xpm[];
extern const char* config_xpm[];
extern const char* copyblock_xpm[];
extern const char* copy_button[];
extern const char* cursor_shape_xpm[];
extern const char* cursor_xpm[];
extern const char* cut_button[];
extern const char* cvpcb_xpm[];
extern const char* dashedline_xpm[];
extern const char* datasheet_xpm[];
extern const char* delete_arc_xpm[];
extern const char* delete_association_xpm[];
extern const char* delete_body_xpm[];
extern const char* delete_bus_xpm[];
extern const char* delete_circle_xpm[];
extern const char* delete_connection_xpm[];
extern const char* delete_cotation_xpm[];
extern const char* delete_field_xpm[];
extern const char* delete_glabel_xpm[];
extern const char* delete_line_xpm[];
extern const char* delete_module_xpm[];
extern const char* delete_net_xpm[];
extern const char* delete_node_xpm[];
extern const char* delete_pad_xpm[];
extern const char* delete_pinsheet_xpm[];
extern const char* delete_pin_xpm[];
extern const char* delete_polygon_xpm[];
extern const char* delete_rectangle_xpm[];
extern const char* delete_segment_xpm[];
extern const char* delete_sheet_xpm[];
extern const char* delete_text_xpm[];
extern const char* delete_track_xpm[];
extern const char* delete_xpm[];
extern const char* directory_xpm[];
extern const char* display_options_xpm[];
extern const char* down_xpm[];
extern const char* drag_module_xpm[];
extern const char* drag_outline_segment_xpm[];
extern const char* drag_pad_xpm[];
extern const char* drag_segment_withslope_xpm[];
extern const char* drag_track_segment_xpm[];
extern const char* drc_off_xpm[];
extern const char* drc_xpm[];
extern const char* edges_sketch_xpm[];
extern const char* edit_comp_footprint_xpm[];
extern const char* edit_component_xpm[];
extern const char* edit_comp_ref_xpm[];
extern const char* edit_comp_value_xpm[];
extern const char* edit_module_xpm[];
extern const char* editor_xpm[];
extern const char* edit_part_xpm[];
extern const char* edit_sheet_xpm[];
extern const char* edit_text_xpm[];
extern const char* edit_xpm[];
extern const char* eeschema_xpm[];
extern const char* enter_sheet_xpm[];
extern const char* erc_xpm[];
extern const char* error_xpm[];
extern const char* exit_xpm[];
extern const char* export_module_xpm[];
extern const char* export_options_pad_xpm[];
extern const char* export_xpm[];
extern const char* file_footprint_xpm[];
extern const char* fill_zone_xpm[];
extern const char* find_xpm[];
extern const char* flag_xpm[];
extern const char* fonts_xpm[];
extern const char* footprint_text_xpm[];
extern const char* general_deletions_xpm[];
extern const char* general_ratsnet_xpm[];
extern const char* glabel2label_xpm[];
extern const char* glabel2text_xpm[];
extern const char* gl_change_xpm[];
extern const char* global_options_pad_xpm[];
extern const char* green_xpm[];
extern const char* grid_select_xpm[];
extern const char* grid_xpm[];
extern const char* hammer_xpm[];
extern const char* help_xpm[];
extern const char* hidden_pin_xpm[];
extern const char* hierarchy_cursor_xpm[];
extern const char* hierarchy_nav_xpm[];
extern const char* icon_cvpcb_small_xpm[];
extern const char* icon_cvpcb_xpm[];
extern const char* icon_eeschema_xpm[];
extern const char* icon_gerbview_small_xpm[];
extern const char* icon_gerbview_xpm[];
extern const char* icon_modedit_xpm[];
extern const char* icon_python_small_xpm[];
extern const char* icon_python_xpm[];
extern const char* icon_txt_xpm[];
extern const char* icon_w3d_xpm[];
extern const char* import_hierarchical_label_xpm[];
extern const char* import_module_xpm[];
extern const char* import_xpm[];
extern const char* import3d_xpm[];
extern const char* info_xpm[];
extern const char* insert_module_board_xpm[];
extern const char* invert_module_xpm[];
extern const char* jigsaw_xpm[];
extern const char* kicad_icon_small_xpm[];
extern const char* kicad_icon_xpm[];
extern const char* label2glabel_xpm[];
extern const char* label2text_xpm[];
extern const char* label_xpm[];
extern const char* lang_catalan_xpm[];
extern const char* lang_chinese_xpm[];
extern const char* lang_cs_xpm[];
extern const char* lang_def_xpm[];
extern const char* lang_de_xpm[];
extern const char* lang_en_xpm[];
extern const char* lang_es_xpm[];
extern const char* lang_fr_xpm[];
extern const char* lang_hu_xpm[];
extern const char* lang_it_xpm[];
extern const char* lang_ko_xpm[];
extern const char* lang_nl_xpm[];
extern const char* lang_pl_xpm[];
extern const char* lang_pt_xpm[];
extern const char* lang_ru_xpm[];
extern const char* lang_sl_xpm[];
extern const char* language_xpm[];
extern const char* leave_sheet_xpm[];
extern const char* left_xpm[];
extern const char* libedit_icon_xpm[];
extern const char* libedit_xpm[];
extern const char* libedit_part_xpm[];
extern const char* lib_next_xpm[];
extern const char* lib_previous_xpm[];
extern const char* library_browse_xpm[];
extern const char* library_update_xpm[];
extern const char* library_xpm[];
extern const char* libview_xpm[];
extern const char* lines90_xpm[];
extern const char* load_module_board_xpm[];
extern const char* load_module_lib_xpm[];
extern const char* local_ratsnet_xpm[];
extern const char* locked_xpm[];
extern const char* mirepcb_xpm[];
extern const char* mirror_H_xpm[];
extern const char* mirror_V_xpm[];
extern const char* modedit_xpm[];
extern const char* mode_module_xpm[];
extern const char* mode_track_xpm[];
extern const char* mod_ratsnest_xpm[];
extern const char* module_check_xpm[];
extern const char* module_edit_xpm[];
extern const char* module_filtered_list_xpm[];
extern const char* module_full_list_xpm[];
extern const char* module_options_xpm[];
extern const char* module_ratsnet_xpm[];
extern const char* module_xpm[];
extern const char* morgan1_xpm[];
extern const char* morgan2_xpm[];
extern const char* move_arc_xpm[];
extern const char* move_circle_xpm[];
extern const char* move_field_xpm[];
extern const char* move_glabel_xpm[];
extern const char* move_line_xpm[];
extern const char* move_module_xpm[];
extern const char* move_pad_xpm[];
extern const char* move_pinsheet_xpm[];
extern const char* move_pin_xpm[];
extern const char* move_polygon_xpm[];
extern const char* move_rectangle_xpm[];
extern const char* move_sheet_xpm[];
extern const char* move_text_xpm[];
extern const char* move_track_segment_xpm[];
extern const char* move_track_xpm[];
extern const char* move_xpm[];
extern const char* mw_Add_Gap_xpm[];
extern const char* mw_Add_Line_xpm[];
extern const char* mw_Add_Shape_xpm[];
extern const char* mw_Add_stub_arc_xpm[];
extern const char* mw_Add_Stub_xpm[];
extern const char* mw_toolbar_xpm[];
extern const char* net_highlight_xpm[];
extern const char* net_hightlight_xpm[];
extern const char* netlist_xpm[];
extern const char* net_locked_xpm[];
extern const char* net_unlocked_xpm[];
extern const char* new_component_xpm[];
extern const char* new_cvpcb_xpm[];
extern const char* new_footprint_xpm[];
extern const char* new_gerb_xpm[];
extern const char* new_library_xpm[];
extern const char* new_module_xpm[];
extern const char* new_pcb_xpm[];
extern const char* new_project_xpm[];
extern const char* new_python_xpm[];
extern const char* new_sch_xpm[];
extern const char* new_txt_xpm[];
extern const char* new_xpm[];
extern const char* noconn_button[];
extern const char* normal_xpm[];
extern const char* open_library_xpm[];
extern const char* open_project_xpm[];
extern const char* open_xpm[];
extern const char* options_all_tracks_and_vias_xpm[];
extern const char* options_all_tracks_xpm[];
extern const char* options_all_vias_xpm[];
extern const char* options_arc_xpm[];
extern const char* options_circle_xpm[];
extern const char* options_module_xpm[];
extern const char* options_new_pad_xpm[];
extern const char* options_pad_xpm[];
extern const char* options_pinsheet_xpm[];
extern const char* options_pin_xpm[];
extern const char* options_rectangle_xpm[];
extern const char* options_segment_xpm[];
extern const char* options_text_xpm[];
extern const char* options_tracks_xpm[];
extern const char* options_track_xpm[];
extern const char* options_vias_xpm[];
extern const char* opt_show_polygon_xpm[];
extern const char* orient_xpm[];
extern const char* pad_sketch_xpm[];
extern const char* pad_xpm[];
extern const char* palette_xpm[];
extern const char* part_properties_xpm[];
extern const char* paste_xpm[];
extern const char* pcbnew_xpm[];
extern const char* pcb_offset_xpm[];
extern const char* pin2pin_xpm[];
extern const char* pin_name_to_xpm[];
extern const char* pin_number_to_xpm[];
extern const char* pin_size_to_xpm[];
extern const char* pin_to_xpm[];
extern const char* pin_xpm[];
extern const char* plot_HPG_xpm[];
extern const char* plot_PS_xpm[];
extern const char* plot_xpm[];
extern const char* polar_coord_xpm[];
extern const char* post_compo_xpm[];
extern const char* post_drill_xpm[];
extern const char* post_module_xpm[];
extern const char* preference_xpm[];
extern const char* print_button[];
extern const char* ratsnest_xpm[];
extern const char* read_setup_xpm[];
extern const char* redo_xpm[];
extern const char* red_xpm[];
extern const char* reload2_xpm[];
extern const char* reload_xpm[];
extern const char* repaint_xpm[];
extern const char* resize_sheet_xpm[];
extern const char* right_xpm[];
extern const char* rotate_field_xpm[];
extern const char* rotate_glabel_xpm[];
extern const char* rotate_module_neg_xpm[];
extern const char* rotate_module_pos_xpm[];
extern const char* rotate_pin_xpm[];
extern const char* rotate_neg_xpm[];
extern const char* rotate_pos_xpm[];
extern const char* rotate_neg_X_xpm[];
extern const char* rotate_pos_X_xpm[];
extern const char* rotate_neg_Y_xpm[];
extern const char* rotate_pos_Y_xpm[];
extern const char* rotate_neg_Z_xpm[];
extern const char* rotate_pos_Z_xpm[];
extern const char* save_as_xpm[];
extern const char* save_cmpstuff_xpm[];
extern const char* save_library_xpm[];
extern const char* save_netlist_xpm[];
extern const char* save_part_in_mem_xpm[];
extern const char* save_project_xpm[];
extern const char* save_setup_xpm[];
extern const char* save_xpm[];
extern const char* schematic_xpm[];
extern const char* select_grid_xpm[];
extern const char* select_layer_pair_xpm[];
extern const char* select_w_layer_xpm[];
extern const char* sheetset_xpm[];
extern const char* show_3d_xpm[];
extern const char* show_dcodenumber_xpm[];
extern const char* show_mod_edge_xpm[];
extern const char* showtrack_xpm[];
extern const char* show_zone_xpm[];
extern const char* show_zone_disable_xpm[];
extern const char* show_zone_outline_only_xpm[];
extern const char* swap_layer_xpm[];
extern const char* text_sketch_xpm[];
extern const char* tool_ratsnet_xpm[];
extern const char* tools_xpm[];
extern const char* track_locked_xpm[];
extern const char* track_sketch_xpm[];
extern const char* track_unlocked_xpm[];
extern const char* transistor_xpm[];
extern const char* tree_nosel_xpm[];
extern const char* tree_sel_xpm[];
extern const char* undelete_xpm[];
extern const char* undo_xpm[];
extern const char* unit_inch_xpm[];
extern const char* unit_mm_xpm[];
extern const char* unknown_xpm[];
extern const char* unlocked_xpm[];
extern const char* unzip_xpm[];
extern const char* update_module_board_xpm[];
extern const char* up_xpm[];
extern const char* viewlibs_icon_xpm[];
extern const char* warning_xpm[];
extern const char* web_support_xpm[];
extern const char* width_net_xpm[];
extern const char* width_segment_xpm[];
extern const char* width_track_via_xpm[];
extern const char* width_track_xpm[];
extern const char* width_vias_xpm[];
extern const char* zip_tool_xpm[];
extern const char* zip_xpm[];
extern const char* zoom_1_xpm[];
extern const char* zoom_center_xpm[];
extern const char* zoomoins3d_xpm[];
extern const char* zoom_redraw_xpm[];
extern const char* zoom_auto_xpm[];
extern const char* zoom_in_xpm[];
extern const char* zoom_out_xpm[];
extern const char* zoompage3d_xpm[];
extern const char* zoom_page_xpm[];
extern const char* zoomplus3d_xpm[];
extern const char* zoomrefr3d_xpm[];
extern const char* zoom_selected_xpm[];
extern const char* zoom_select_xpm[];
extern const char* zoom_xpm[];

==> kicad_0.0.20100314.orig.tar.gz: kicad-0.0.20100314.orig/kicad/include/bitmaps.h <==

#define VTOOLBAR_WIDTH  26

#define TOOL_SIZE       23

// Please keep list sorted alphabetically, ignoring case.

extern const char* shape_3d_xpm[];
extern const char* add_arc_xpm[];
extern const char* add_bus2bus_xpm[];
extern const char* add_bus_xpm[];
extern const char* add_circle_xpm[];
extern const char* add_component_xpm[];
extern const char* add_corner_xpm[];
extern const char* add_dashed_line_xpm[];
extern const char* add_dimension_xpm[];
extern const char* add_entry_xpm[];
extern const char* add_glabel_xpm[];
extern const char* add_hierarchical_label_xpm[];
extern const char* add_hierarchical_subsheet_xpm[];
extern const char* add_hierar_pin_xpm[];
extern const char* add_junction_xpm[];
extern const char* add_line2bus_xpm[];
extern const char* add_line_label_xpm[];
extern const char* add_line_xpm[];
extern const char* add_mires_xpm[];
extern const char* add_polygon_xpm[];
extern const char* add_power_xpm[];
extern const char* add_rectangle_xpm[];
extern const char* add_text_xpm[];
extern const char* add_tracks_xpm[];
extern const char* add_zone_cutout[];
extern const char* add_zone_xpm[];
extern const char* a_icon_pcbnew_xpm[];
extern const char* anchor_xpm[];
extern const char* annotate_down_right_xpm[];
extern const char* annotate_right_down_xpm[];
extern const char* annotate_xpm[];
extern const char* apply_xpm[];
extern const char* auto_associe_xpm[];
extern const char* auto_delete_track_xpm[];
extern const char* auto_track_width_xpm[];
extern const char* axis3d_back_xpm[];
extern const char* axis3d_bottom_xpm[];
extern const char* axis3d_front_xpm[];
extern const char* axis3d_left_xpm[];
extern const char* axis3d_right_xpm[];
extern const char* axis3d_top_xpm[];
extern const char* axis3d_xpm[];
extern const char* backanno_xpm[];
extern const char* book_xpm[];
extern const char* break_bus_xpm[];
extern const char* break_line_xpm[];
extern const char* browse_files_xpm[];
extern const char* cancel_tool_xpm[];
extern const char* cancel_xpm[];
extern const char* checked_ok_xpm[];
extern const char* component_select_alternate_shape_xpm[];
extern const char* component_select_unit_xpm[];
extern const char* config_xpm[];
extern const char* copper_layers_setup_xpm[];
extern const char* copyblock_xpm[];
extern const char* copy_button[];
extern const char* cursor_shape_xpm[];
extern const char* cursor_xpm[];
extern const char* cut_button[];
extern const char* cvpcb_xpm[];
extern const char* dashedline_xpm[];
extern const char* datasheet_xpm[];
extern const char* delete_arc_xpm[];
extern const char* delete_association_xpm[];
extern const char* delete_body_xpm[];
extern const char* delete_bus_xpm[];
extern const char* delete_circle_xpm[];
extern const char* delete_connection_xpm[];
extern const char* delete_cotation_xpm[];
extern const char* delete_field_xpm[];
extern const char* delete_glabel_xpm[];
extern const char* delete_line_xpm[];
extern const char* delete_module_xpm[];
extern const char* delete_net_xpm[];
extern const char* delete_node_xpm[];
extern const char* delete_pad_xpm[];
extern const char* delete_pinsheet_xpm[];
extern const char* delete_pin_xpm[];
extern const char* delete_polygon_xpm[];
extern const char* delete_rectangle_xpm[];
extern const char* delete_segment_xpm[];
extern const char* delete_sheet_xpm[];
extern const char* delete_text_xpm[];
extern const char* delete_track_xpm[];
extern const char* delete_xpm[];
extern const char* directory_xpm[];
extern const char* display_options_xpm[];
extern const char* down_xpm[];
extern const char* drag_module_xpm[];
extern const char* drag_outline_segment_xpm[];
extern const char* drag_pad_xpm[];
extern const char* drag_segment_withslope_xpm[];
extern const char* drag_track_segment_xpm[];
extern const char* drc_off_xpm[];
extern const char* drc_xpm[];
extern const char* edges_sketch_xpm[];
extern const char* edit_comp_footprint_xpm[];
extern const char* edit_component_xpm[];
extern const char* edit_comp_ref_xpm[];
extern const char* edit_comp_value_xpm[];
extern const char* edit_module_xpm[];
extern const char* editor_xpm[];
extern const char* edit_part_xpm[];
extern const char* edit_sheet_xpm[];
extern const char* edit_text_xpm[];
extern const char* edit_xpm[];
extern const char* eeschema_xpm[];
extern const char* enter_sheet_xpm[];
extern const char* erc_xpm[];
extern const char* erc_green_xpm[];
extern const char* error_xpm[];
extern const char* exit_xpm[];
extern const char* export_module_xpm[];
extern const char* export_options_pad_xpm[];
extern const char* export_xpm[];
extern const char* fabrication_xpm[];
extern const char* file_footprint_xpm[];
extern const char* fill_zone_xpm[];
extern const char* find_xpm[];
extern const char* flag_xpm[];
extern const char* fonts_xpm[];
extern const char* footprint_text_xpm[];
extern const char* general_deletions_xpm[];
extern const char* general_ratsnet_xpm[];
extern const char* glabel2label_xpm[];
extern const char* glabel2text_xpm[];
extern const char* gl_change_xpm[];
extern const char* global_options_pad_xpm[];
extern const char* green_xpm[];
extern const char* grid_select_xpm[];
extern const char* grid_xpm[];
extern const char* hammer_xpm[];
extern const char* help_xpm[];
extern const char* hidden_pin_xpm[];
extern const char* hierarchy_cursor_xpm[];
extern const char* hierarchy_nav_xpm[];
extern const char* hotkeys_xpm[];
extern const char* icon_cvpcb_small_xpm[];
extern const char* icon_cvpcb_xpm[];
extern const char* icon_eeschema_xpm[];
extern const char* icon_gerbview_small_xpm[];
extern const char* icon_gerbview_xpm[];
extern const char* icon_modedit_xpm[];
extern const char* icon_txt_xpm[];
extern const char* icon_w3d_xpm[];
extern const char* import_hierarchical_label_xpm[];
extern const char* import_module_xpm[];
extern const char* import_xpm[];
extern const char* import3d_xpm[];
extern const char* info_xpm[];
extern const char* insert_module_board_xpm[];
extern const char* invert_module_xpm[];
extern const char* invisible_text_xpm[];
extern const char* jigsaw_xpm[];
extern const char* kicad_icon_small_xpm[];
extern const char* kicad_icon_xpm[];
extern const char* label2glabel_xpm[];
extern const char* label2text_xpm[];
extern const char* label_xpm[];
extern const char* lang_catalan_xpm[];
extern const char* lang_chinese_xpm[];
extern const char* lang_cs_xpm[];
extern const char* lang_def_xpm[];
extern const char* lang_de_xpm[];
extern const char* lang_en_xpm[];
extern const char* lang_es_xpm[];
extern const char* lang_fr_xpm[];
extern const char* lang_fi_xpm[];
extern const char* lang_hu_xpm[];
extern const char* lang_it_xpm[];
extern const char* lang_ko_xpm[];
extern const char* lang_nl_xpm[];
extern const char* lang_pl_xpm[];
extern const char* lang_pt_xpm[];
extern const char* lang_ru_xpm[];
extern const char* lang_sl_xpm[];
extern const char* language_xpm[];
extern const char* layers_manager_xpm[];
extern const char* leave_sheet_xpm[];
extern const char* left_xpm[];
extern const char* libedit_icon_xpm[];
extern const char* libedit_xpm[];
extern const char* libedit_part_xpm[];
extern const char* lib_next_xpm[];
extern const char* lib_previous_xpm[];
extern const char* library_browse_xpm[];
extern const char* library_update_xpm[];
extern const char* library_xpm[];
extern const char* libview_xpm[];
extern const char* lines90_xpm[];
extern const char* load_module_board_xpm[];
extern const char* load_module_lib_xpm[];
extern const char* local_ratsnet_xpm[];
extern const char* locked_xpm[];
extern const char* mirepcb_xpm[];
extern const char* mirror_H_xpm[];
extern const char* mirror_V_xpm[];
extern const char* modedit_xpm[];
extern const char* mode_module_xpm[];
extern const char* mode_track_xpm[];
extern const char* mod_ratsnest_xpm[];
extern const char* module_check_xpm[];
extern const char* module_edit_xpm[];
extern const char* module_filtered_list_xpm[];
extern const char* module_full_list_xpm[];
extern const char* module_options_xpm[];
extern const char* module_ratsnet_xpm[];
extern const char* module_xpm[];
extern const char* morgan1_xpm[];
extern const char* morgan2_xpm[];
extern const char* move_arc_xpm[];
extern const char* move_circle_xpm[];
extern const char* move_field_xpm[];
extern const char* move_glabel_xpm[];
extern const char* move_line_xpm[];
extern const char* move_module_xpm[];
extern const char* move_pad_xpm[];
extern const char* move_pinsheet_xpm[];
extern const char* move_pin_xpm[];
extern const char* move_polygon_xpm[];
extern const char* move_rectangle_xpm[];
extern const char* move_sheet_xpm[];
extern const char* move_text_xpm[];
extern const char* move_track_segment_xpm[];
extern const char* move_track_xpm[];
extern const char* move_xpm[];
extern const char* mw_Add_Gap_xpm[];
extern const char* mw_Add_Line_xpm[];
extern const char* mw_Add_Shape_xpm[];
extern const char* mw_Add_stub_arc_xpm[];
extern const char* mw_Add_Stub_xpm[];
extern const char* mw_toolbar_xpm[];
extern const char* net_highlight_xpm[];
extern const char* netlist_xpm[];
extern const char* net_locked_xpm[];
extern const char* net_unlocked_xpm[];
extern const char* new_component_xpm[];
extern const char* new_cvpcb_xpm[];
extern const char* new_footprint_xpm[];
extern const char* new_gerb_xpm[];
extern const char* new_library_xpm[];
extern const char* new_module_xpm[];
extern const char* new_pcb_xpm[];
extern const char* new_project_xpm[];
extern const char* new_python_xpm[];
extern const char* new_sch_xpm[];
extern const char* new_txt_xpm[];
extern const char* new_xpm[];
extern const char* noconn_button[];
extern const char* normal_xpm[];
extern const char* open_library_xpm[];
extern const char* open_project_xpm[];
extern const char* open_xpm[];
extern const char* options_all_tracks_and_vias_xpm[];
extern const char* options_all_tracks_xpm[];
extern const char* options_all_vias_xpm[];
extern const char* options_arc_xpm[];
extern const char* options_circle_xpm[];
extern const char* options_module_xpm[];
extern const char* options_new_pad_xpm[];
extern const char* options_pad_xpm[];
extern const char* options_pinsheet_xpm[];
extern const char* options_pin_xpm[];
extern const char* options_rectangle_xpm[];
extern const char* options_segment_xpm[];
extern const char* options_text_xpm[];
extern const char* options_tracks_xpm[];
extern const char* options_track_xpm[];
extern const char* options_vias_xpm[];
extern const char* opt_show_polygon_xpm[];
extern const char* orient_xpm[];
extern const char* pad_sketch_xpm[];
extern const char* pad_xpm[];
extern const char* pads_mask_layers_xpm[];
extern const char* palette_xpm[];
extern const char* part_properties_xpm[];
extern const char* paste_xpm[];
extern const char* pcbnew_xpm[];
extern const char* pcb_offset_xpm[];
extern const char* pin2pin_xpm[];
extern const char* pin_name_to_xpm[];
extern const char* pin_number_to_xpm[];
extern const char* pin_size_to_xpm[];
extern const char* pinorient_right_xpm[];
extern const char* pinorient_left_xpm[];
extern const char* pinorient_up_xpm[];
extern const char* pinorient_down_xpm[];
extern const char* pinshape_normal_xpm[];
extern const char* pinshape_invert_xpm[];
extern const char* pinshape_clock_normal_xpm[];
extern const char* pinshape_clock_invert_xpm[];
extern const char* pinshape_active_low_input_xpm[];
extern const char* pinshape_clock_active_low_xpm[];
extern const char* pinshape_active_low_output_xpm[];
extern const char* pintype_input_xpm[];
extern const char* pintype_output_xpm[];
extern const char* pintype_bidi_xpm[];
extern const char* pintype_3states_xpm[];
extern const char* pintype_passive_xpm[];
extern const char* pintype_notspecif_xpm[];
extern const char* pintype_powerinput_xpm[];
extern const char* pintype_poweroutput_xpm[];
extern const char* pintype_opencoll_xpm[];
extern const char* pintype_openemit_xpm[];
extern const char* pintype_noconnect_xpm[];
extern const char* pin_to_xpm[];
extern const char* pin_xpm[];
extern const char* plot_HPG_xpm[];
extern const char* plot_PS_xpm[];
extern const char* plot_xpm[];
extern const char* polar_coord_xpm[];
extern const char* post_compo_xpm[];
extern const char* post_drill_xpm[];
extern const char* post_module_xpm[];
extern const char* preference_xpm[];
extern const char* print_button[];
extern const char* ratsnest_xpm[];
extern const char* read_setup_xpm[];
extern const char* redo_xpm[];
extern const char* red_xpm[];
extern const char* reload2_xpm[];
extern const char* reload_xpm[];
extern const char* repaint_xpm[];
extern const char* resize_sheet_xpm[];
extern const char* right_xpm[];
extern const char* rotate_field_xpm[];
extern const char* rotate_glabel_xpm[];
extern const char* rotate_module_neg_xpm[];
extern const char* rotate_module_pos_xpm[];
extern const char* rotate_pin_xpm[];
extern const char* rotate_neg_xpm[];
extern const char* rotate_pos_xpm[];
extern const char* rotate_neg_X_xpm[];
extern const char* rotate_pos_X_xpm[];
extern const char* rotate_neg_Y_xpm[];
extern const char* rotate_pos_Y_xpm[];
extern const char* rotate_neg_Z_xpm[];
extern const char* rotate_pos_Z_xpm[];
extern const char* save_as_xpm[];
extern const char* save_cmpstuff_xpm[];
extern const char* save_library_xpm[];
extern const char* save_netlist_xpm[];
extern const char* save_part_in_mem_xpm[];
extern const char* save_project_xpm[];
extern const char* save_setup_xpm[];
extern const char* save_xpm[];
extern const char* schematic_xpm[];
extern const char* select_grid_xpm[];
extern const char* select_layer_pair_xpm[];
extern const char* select_w_layer_xpm[];
extern const char* sheetset_xpm[];
extern const char* show_3d_xpm[];
extern const char* show_dcodenumber_xpm[];
extern const char* show_mod_edge_xpm[];
extern const char* showtrack_xpm[];
extern const char* show_zone_xpm[];
extern const char* show_zone_disable_xpm[];
extern const char* show_zone_outline_only_xpm[];
extern const char* swap_layer_xpm[];
extern const char* text_sketch_xpm[];
extern const char* tool_ratsnet_xpm[];
extern const char* tools_xpm[];
extern const char* track_locked_xpm[];
extern const char* track_sketch_xpm[];
extern const char* track_unlocked_xpm[];
extern const char* transistor_xpm[];
extern const char* tree_nosel_xpm[];
extern const char* tree_sel_xpm[];
extern const char* undelete_xpm[];
extern const char* undo_xpm[];
extern const char* unit_inch_xpm[];
extern const char* unit_mm_xpm[];
extern const char* unknown_xpm[];
extern const char* unlocked_xpm[];
extern const char* unzip_xpm[];
extern const char* update_module_board_xpm[];
extern const char* up_xpm[];
extern const char* via_sketch_xpm[];
extern const char* viewlibs_icon_xpm[];
extern const char* warning_xpm[];
extern const char* web_support_xpm[];
extern const char* width_net_xpm[];
extern const char* width_segment_xpm[];
extern const char* width_track_via_xpm[];
extern const char* width_track_xpm[];
extern const char* width_vias_xpm[];
extern const char* zip_tool_xpm[];
extern const char* zip_xpm[];
extern const char* zoom_1_xpm[];
extern const char* zoom_center_xpm[];
extern const char* zoomoins3d_xpm[];
extern const char* zoom_redraw_xpm[];
extern const char* zoom_auto_xpm[];
extern const char* zoom_in_xpm[];
extern const char* zoom_out_xpm[];
extern const char* zoompage3d_xpm[];
extern const char* zoom_page_xpm[];
extern const char* zoomplus3d_xpm[];
extern const char* zoomrefr3d_xpm[];
extern const char* zoom_selected_xpm[];
extern const char* zoom_select_xpm[];
extern const char* zoom_xpm[];
